@@ -1,7 +1,9 @@
 from django import template
 
 from django.utils.encoding import smart_unicode
+from django.contrib.staticfiles import finders
 from django.contrib.staticfiles.storage import staticfiles_storage
+from django.conf import settings
 
 from django_inlinecss import conf
 
@@ -20,7 +22,10 @@ class InlineCssNode(template.Node):
             path = expression.resolve(context, True)
             if path is not None:
                 path = smart_unicode(path)
-            expanded_path = staticfiles_storage.path(path)
+            if settings.DEBUG:
+                expanded_path = finders.find(path)
+            else:
+                expanded_path = staticfiles_storage.path(path)
 
             with open(expanded_path) as css_file:
                 css = ''.join((css, css_file.read()))
